from pathlib import Path

TESTS_DIR = Path(__file__).parent
INPUT_FILES_DIR = TESTS_DIR / "input_files"

TERMINHTML_DEMO_GIF = INPUT_FILES_DIR / "terminhtml-demo.gif"
TERMINHTML_DEMO_HTML = INPUT_FILES_DIR / "terminhtml-demo.html"
