"""
Create video and image files via TerminHTML rather than HTML/CSS/JS
"""
from terminhtml_recorder.formats import OutputFormat
from terminhtml_recorder.recorder import (
    PageLocators,
    TerminHTMLRecorder,
    default_page_interactor,
)
